public inbox for pbs-devel@lists.proxmox.com
 help / color / mirror / Atom feed
From: Dietmar Maurer <dietmar@proxmox.com>
To: pbs-devel@lists.proxmox.com
Subject: [pbs-devel] [PATCH proxmox-backup 14/15] proxmox-rrd: rename last_counter to last_value
Date: Wed, 13 Oct 2021 10:24:51 +0200	[thread overview]
Message-ID: <20211013082452.619406-15-dietmar@proxmox.com> (raw)
In-Reply-To: <20211013082452.619406-1-dietmar@proxmox.com>

---
 proxmox-rrd/src/rrd.rs    | 25 +++++++++++++++----------
 proxmox-rrd/src/rrd_v1.rs |  2 +-
 2 files changed, 16 insertions(+), 11 deletions(-)

diff --git a/proxmox-rrd/src/rrd_v1.rs b/proxmox-rrd/src/rrd_v1.rs
index 511b510b..7e4b97c2 100644
--- a/proxmox-rrd/src/rrd_v1.rs
+++ b/proxmox-rrd/src/rrd_v1.rs
@@ -285,7 +285,7 @@ impl RRDv1 {
 
         let source = DataSource {
             dst,
-            counter_value: f64::NAN,
+            last_value: f64::NAN,
             last_update:  self.hour_avg.last_update, // IMPORTANT!
         };
         Ok(RRD {
diff --git a/proxmox-rrd/src/rrd.rs b/proxmox-rrd/src/rrd.rs
index 7901fe39..72769bfd 100644
--- a/proxmox-rrd/src/rrd.rs
+++ b/proxmox-rrd/src/rrd.rs
@@ -63,7 +63,7 @@ pub struct DataSource {
     pub last_update: f64,
     /// Stores the last value, used to compute differential value for
     /// derive/counters
-    pub counter_value: f64,
+    pub last_value: f64,
 }
 
 impl DataSource {
@@ -72,7 +72,7 @@ impl DataSource {
         Self {
             dst,
             last_update: 0.0,
-            counter_value: f64::NAN,
+            last_value: f64::NAN,
         }
     }
 
@@ -94,23 +94,24 @@ impl DataSource {
         if is_counter || self.dst == DST::Derive {
             let time_diff = time - self.last_update;
 
-            let diff = if self.counter_value.is_nan() {
+            let diff = if self.last_value.is_nan() {
                 0.0
             } else if is_counter && value < 0.0 {
                 bail!("got negative value for counter");
-            } else if is_counter && value < self.counter_value {
+            } else if is_counter && value < self.last_value {
                 // Note: We do not try automatic overflow corrections, but
                 // we update counter_value anyways, so that we can compute the diff
                 // next time.
-                self.counter_value = value;
+                self.last_value = value;
                 bail!("conter overflow/reset detected");
             } else {
-                value - self.counter_value
+                value - self.last_value
             };
-            self.counter_value = value;
             value = diff/time_diff;
         }
 
+        self.last_value = value;
+
         Ok(value)
     }
 
@@ -138,11 +139,15 @@ impl RRA {
         }
     }
 
-    fn slot_end_time(&self, time: u64) -> u64 {
+    pub fn slot_end_time(&self, time: u64) -> u64 {
         self.resolution*(time/self.resolution + 1)
     }
 
-    fn slot(&self, time: u64) -> usize {
+    pub fn slot_start_time(&self, time: u64) -> u64 {
+        self.resolution*(time/self.resolution)
+    }
+
+    pub fn slot(&self, time: u64) -> usize {
         ((time/self.resolution) as usize) % self.data.len()
     }
 
@@ -94,23 +94,24 @@ impl DataSource {
                 // Note: We do not try automatic overflow corrections, but
-                // we update counter_value anyways, so that we can compute the diff
+                // we update last_value anyways, so that we can compute the diff
                 // next time.
-- 
2.30.2





  parent reply	other threads:[~2021-10-13  8:25 UTC|newest]

Thread overview: 18+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2021-10-13  8:24 [pbs-devel] [PATCH proxmox-backup 00/15] RRD database improvements Dietmar Maurer
2021-10-13  8:24 ` [pbs-devel] [PATCH proxmox-backup 01/15] proxmox-rrd: use a journal to reduce amount of bytes written Dietmar Maurer
2021-10-13  8:24 ` [pbs-devel] [PATCH proxmox-backup 02/15] RRD_CACHE: use a OnceCell instead of lazy_static Dietmar Maurer
2021-10-13  8:24 ` [pbs-devel] [PATCH proxmox-backup 03/15] proxmox-backup-proxy: use tokio::task::spawn_blocking instead of block_in_place Dietmar Maurer
2021-10-13  8:24 ` [pbs-devel] [PATCH proxmox-backup 04/15] proxmox-rrd: implement new CBOR based format Dietmar Maurer
2021-10-13  8:24 ` [pbs-devel] [PATCH proxmox-backup 05/15] proxmox-rrd: remove dependency to proxmox-rrd-api-types Dietmar Maurer
2021-10-13  8:24 ` [pbs-devel] [PATCH proxmox-backup 06/15] proxmox-rrd: extract_data: include values from current slot Dietmar Maurer
2021-10-13  8:24 ` [pbs-devel] [PATCH proxmox-backup 07/15] remove proxmox-rrd-api-types crate, s/RRDTimeFrameResolution/RRDTimeFrame/ Dietmar Maurer
2021-10-13  8:24 ` [pbs-devel] [PATCH proxmox-backup 08/15] proxmox-rrd: support CF::Last Dietmar Maurer
2021-10-13  8:24 ` [pbs-devel] [PATCH proxmox-backup 09/15] proxmox-rrd: split out load_rrd (cleanup) Dietmar Maurer
2021-10-13  8:24 ` [pbs-devel] [PATCH proxmox-backup 10/15] proxmox-rrd: add binary to create/manage rrd files Dietmar Maurer
2021-10-13  8:24 ` [pbs-devel] [PATCH proxmox-backup 11/15] proxmox-rrd: avoid % inside loop Dietmar Maurer
2021-10-13  8:24 ` [pbs-devel] [PATCH proxmox-backup 12/15] proxmox-rrd: new helper methods - slot() and slot_end_time() Dietmar Maurer
2021-10-13  8:24 ` [pbs-devel] [PATCH proxmox-backup 13/15] proxmox-rrd: protect against negative update time Dietmar Maurer
2021-10-13  8:24 ` Dietmar Maurer [this message]
2021-10-13  8:24 ` [pbs-devel] [PATCH proxmox-backup 15/15] proxmox-rrd: add more commands to the rrd cli tool Dietmar Maurer
2021-10-13 11:58 ` [pbs-devel] applied-series: [PATCH proxmox-backup 00/15] RRD database improvements Thomas Lamprecht
2021-10-13  9:51 [pbs-devel] [PATCH proxmox-backup 14/15] proxmox-rrd: rename last_counter to last_value Dietmar Maurer

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20211013082452.619406-15-dietmar@proxmox.com \
    --to=dietmar@proxmox.com \
    --cc=pbs-devel@lists.proxmox.com \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox
Service provided by Proxmox Server Solutions GmbH | Privacy | Legal